@@ -2,20 +2,19 @@
 use gura::{dump, parse, GuraType};
 
 fn main() {
-    let gura_string = "
+    let gura_string = r##"
 # This is a Gura document.
-title: \"Gura Example\"
+title: "Gura Example"
 
 an_object:
-    username: \"Stephen\"
-    pass: \"Hawking\"
+    username: "Stephen"
+    pass: "Hawking"
 
 # Line breaks are OK when inside arrays
 hosts: [
-  \"alpha\",
-  \"omega\"
-]"
-    .to_string();
+  "alpha",
+  "omega"
+]"##;
 
     // Parse: transforms a Gura string into a dictionary
     let parsed = parse(&gura_string).unwrap();
